<?php

declare(strict_types = 1);

namespace Drupal\public_key_credential_source;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\user\EntityOwnerInterface;
use Webauthn\PublicKeyCredentialSource as PKCredentialSource;

/**
 * Provides an interface defining a public key credential source entity type.
 *
 * Originally from the webauthn module.
 */
interface PublicKeyCredentialSourceInterface extends ContentEntityInterface, EntityOwnerInterface {

  /**
   * Creates an instance from a source object.
   *
   * @param \Webauthn\PublicKeyCredentialSource $source
   *   The source object.
   *
   * @return static
   *   A new instance.
   */
  public static function createFromSourceObject(PKCredentialSource $source): self;

  /**
   * Gets the actual source object.
   *
   * In most cases, this object will be generated based on Drupal field values.
   *
   * @return \Webauthn\PublicKeyCredentialSource
   *   The source object.
   */
  public function getPublicKeyCredentialSource(): PKCredentialSource;

  /**
   * Gets the public key ID.
   *
   * @return string|null
   *   The public key ID.
   */
  public function getPublicKeyCredentialId(): ?string;

  /**
   * Gets the device AAGUID.
   *
   * @return string|null
   *   The device AAGUID.
   */
  public function getDeviceId(): ?string;

  /**
   * Gets the number of public key usages.
   *
   * @return int
   *   The number of usages. Defaults to 0 when the key is created.
   */
  public function getCounter(): int;

}
